# -*- rpm-spec -*-

# Version options
%define kernel_base_version	2.6.16
%define kernel_extra_version	%nil
# Numeric extra version scheme developed by Alexander Bokovoy:
# 0.0.X -- preX
# 0.X.0 -- rcX
# 1.0.0 -- release
%define kernel_extra_version_numeric 1.0.0
%define krelease aw0

%define base_flavour	std26
%define xen_flavour	xen0
%define flavour		%base_flavour-%xen_flavour

# Build options
# You can change compiler version by editing this line:
%define kgcc_version	3.4

%define xen_version	3.0.2
%define xen_kernel_version_patch	2.6.16.13

# Enable/disable SGML docs formatting
%def_disable docs
%def_disable oss_sound

#Versioning
#add_patch_list kernel-ver-update

# Fixes

# Features:

#add_patch_list kernel-feat-drivers-drm
#add_patch_list kernel-feat-drivers-video-splash
#add_patch_list kernel-feat-drivers-input
%add_patch_list kernel-feat-drivers-net-sk98lin
#add_patch_list kernel-feat-drivers-pktcdvd
%add_patch_list kernel-feat-fs-squashfs
#add_patch_list kernel-feat-net-ieee80211
#add_patch_list kernel-feat-net-ppp-mppe
%add_patch_list kernel-feat-evms-nodm

# imz: Unicode support in VT/console
#add_patch_list kernel-feat-drivers-console-unicode
# Although this patch changes the interface between the kernel and loadkeys,
# I do not put a Conflicts for the old console-tools here,
# because the old loadkeys works fine the new kernel interface.

## Don't edit below this line ##################################

%define kversion	%kernel_base_version%kernel_extra_version
%define modules_dir	/lib/modules/%kversion-%flavour-%krelease

Name: kernel-image-%flavour
Version: %kernel_base_version
Release: %krelease

Summary: The Linux kernel (the core of the Linux operating system)
License: GPL
Group: System/Kernel and hardware
Url: http://www.kernel.org/
Packager: Kernel Maintainers Team <kernel@packages.altlinux.org>

%set_kernel_arches i586 x86_64

ExclusiveOS: Linux

BuildRequires: dev86 flex
BuildRequires: libdb4-devel
BuildRequires: gcc%kgcc_version
BuildRequires: kernel-source-%{kernel_base_version} = %{kernel_extra_version_numeric}
BuildRequires: kernel-source-xen-%{kernel_base_version} >= %{xen_version}
BuildRequires: kernel-build-tools >= 0.8, modutils >= 2.4.27-alt1
BuildRequires: %get_patch_list
BuildRequires: kernel-source-xen-%kernel_base_version

%if_enabled docs
BuildRequires: xmlto transfig ghostscript
%endif

%if_enabled ccache
BuildRequires: ccache
%endif

%ifdef use_ccache
BuildRequires: ccache
%endif

Requires: bootloader-utils >= 0.3-alt1
Requires: modutils >= 2.4.27-alt1
Requires: mkinitrd >= 1:2.9.9-alt1
Requires: startup >= 0.8.3-alt1
Requires: xen >= %xen_version

Provides: kernel = %kversion

Prereq: coreutils
Prereq: modutils >= 2.4.27
Prereq: mkinitrd >= 1:2.9.9-alt1

%description
This package contains the Linux kernel that is used to boot and run
your system.

The "std26" variant of kernel packages is a generic 2.6.x kernel which
should support wide range of hardware, but does not contain patches
which are useful only for some special applications (and may have
undesirable side effects in other cases).  This is the default 2.6.x
kernel variant for ALT Linux distributions.

Most hardware drivers for this kernel are built as modules.  Some of
these drivers are built separately from the kernel; they are available
in separate packages (kernel-modules-*-%flavour).

Patches included:%format_patch_list

%if_enabled oss_sound
%package -n kernel-modules-oss-%flavour
Summary: OSS sound driver modules (obsolete)
Group: System/Kernel and hardware
Provides:  kernel-modules-oss-%kversion-%flavour-%krelease = %version-%release
Conflicts: kernel-modules-oss-%kversion-%flavour-%krelease < %version-%release
Conflicts: kernel-modules-oss-%kversion-%flavour-%krelease > %version-%release
Prereq: coreutils
Prereq: modutils
Prereq: %name = %version-%release
Requires(postun): %name = %version-%release

%description -n kernel-modules-oss-%flavour
This package contains OSS sound driver modules for the Linux kernel
package %name-%version-%release.

These drivers are declared obsolete by the kernel maintainers; ALSA
drivers should be used instead.  However, the older OSS drivers may be
still useful for some hardware, if the corresponding ALSA drivers do
not work well.

Install this package only if you really need it.

%endif

%package -n kernel-headers-%flavour
Summary: Header files for the Linux kernel
Group: System/Kernel and hardware
Requires: kernel-headers-common >= 1.1.5
Provides: kernel-headers = %version

%description -n kernel-headers-%flavour
This package makes Linux kernel headers corresponding to the Linux
kernel package %name-%version-%release available for building
userspace programs (if this version of headers is selected by
adjust_kernel_headers).

Note that such usage of kernel headers in userspace is not supported
by the upstream kernel maintainers and often breaks compilation.
Therefore installing and using this package is not recommended.

%package -n kernel-headers-modules-%flavour
Summary: Headers and other files needed for building kernel modules
Group: System/Kernel and hardware
Requires: kernel-headers-%flavour = %version-%release
Requires: gcc%kgcc_version

%description -n kernel-headers-modules-%flavour
This package contains header files, Makefiles and other parts of the
Linux kernel build system which are needed to build kernel modules for
the Linux kernel package %name-%version-%release.

If you need to compile a third-party kernel module for the Linux
kernel package %name-%version-%release, install this package
and specify %_prefix/src/linux-%version-%flavour as the kernel source
directory.

%package -n kernel-doc-%base_flavour
Summary: Linux kernel %kversion-%base_flavour documentation
Group: System/Kernel and hardware

%description -n kernel-doc-%base_flavour
This package contains documentation files for ALT Linux kernel packages:
 * kernel-image-%base_flavour-up-%kversion-%krelease
 * kernel-image-%base_flavour-smp-%kversion-%krelease

The documentation files contained in this package may be different
from the similar files in upstream kernel distributions, because some
patches applied to the corresponding kernel packages may change things
in the kernel and update the documentation to reflect these changes.

%prep
%setup -cT -n kernel-image-%flavour-%kversion-%krelease
%__rm -rf kernel-source-%kernel_base_version
%__tar -jxf %kernel_src/xen-source-%kernel_base_version-%xen_version.tar.bz2
%__tar -jxf %kernel_src/kernel-source-%kernel_base_version.tar.bz2

pushd kernel-source-%kernel_base_version

echo "patches = %_patch_list"

%apply_patches 2.6

# this file should be usable both with make and sh (for broken modules
# which do not use the kernel makefile system)
echo 'export GCC_VERSION=%kgcc_version' > gcc_version.inc

%__subst 's/CC.*$(CROSS_COMPILE)gcc/CC         := $(shell echo $${GCC_USE_CCACHE:+ccache}) gcc-%kgcc_version/g' Makefile

# get rid of unwanted files resulting from patch fuzz
find . -name "*.orig" -delete -or -name "*~" -delete

popd

%__mv kernel-source-%kernel_base_version pristine-linux-%kernel_base_version

pushd buildconfigs
# We already have linux sources so remove getting and preparing kernel sources section 
%__mv Rules.mk Rules.mk.old
cat Rules.mk.old | grep -v -e '\(tmp-pristine\|wget\)' >Rules.mk

# Fixing kernel version for xen
%__subst 's/LINUX_VER[[:space:]]*=.*/LINUX_VER = %kernel_base_version/g' mk.linux-2.6-xen
popd

ln -s linux-%xen_kernel_version_patch patches/linux-%kernel_base_version

make prep-kernels KERNELS="linux-2.6-%xen_flavour" 

%setup -D -T -n kernel-image-%flavour-%kversion-%krelease/linux-%kernel_base_version-%xen_flavour

%__subst 's/EXTRAVERSION[[:space:]]*=.*/EXTRAVERSION = %kernel_extra_version-%flavour-%krelease/g' Makefile

%build

KernelVer=%kversion-%flavour-%krelease

export ARCH=%base_arch

set

echo "Building Kernel $KernelVer"

%make_build mrproper

%__cp -vf %{get_kernel_config %_target_cpu} .config

%make_build oldconfig
%make_build include/linux/version.h
%make_build vmlinuz
%make_build modules

echo "Kernel built $KernelVer"

%if_enabled docs
# psdocs, pdfdocs don't work yet
%make_build htmldocs
%endif


%install
KernelVer=%kversion-%flavour-%krelease

%__install -Dp -m644 System.map %buildroot/boot/System.map-$KernelVer
%__install -Dp -m644 vmlinuz %buildroot/boot/vmlinuz-$KernelVer
%__install -Dp -m644 .config %buildroot/boot/config-$KernelVer

%__make modules_install INSTALL_MOD_PATH=%buildroot

%__install -d %buildroot%_prefix/include/linux-%version-%flavour/include

pushd include
%__cp -a . %buildroot%_prefix/include/linux-%version-%flavour/include
popd

# remove asm-* include files for other architectures
pushd %buildroot%prefix/include/linux-%version-%flavour/include
for dir in asm-*; do
	[ "$dir" = "asm-generic" ] && continue
	[ "$dir" = "asm-%base_arch" ] && continue
	%__rm -rf -- "$dir"
done
popd

# drivers-headers install
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/md
%__install -d %buildroot%_prefix/src/linux-%version-%flavour/drivers/media/video
%__cp -a drivers/scsi/{{scsi,hosts,scsi_typedefs}.h,scsi_module.c} \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/scsi/
%__cp -a drivers/char/drm/{drm,drm_os_linux,drmP}.h \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/char/drm/
%__cp -a drivers/md/dm*.h \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/md/
%__cp -a drivers/media/video/{bt848,btcx-risc,bttv,bttvp}.h \
	%buildroot%_prefix/src/linux-%version-%flavour/drivers/media/video/

%__install -d %buildroot%_prefix/src/linux-%version-%flavour
pushd %buildroot%_prefix/src/linux-%version-%flavour
%__ln_s -f ../../include/linux-%version-%flavour/include ./include
popd

# Install files required for building external modules (in addition to headers)
KbuildFiles="
	Makefile
	Module.symvers
	arch/%base_arch/Makefile
	arch/%base_arch/Makefile.cpu

	scripts/pnmtologo
	scripts/mod/modpost
	scripts/mkmakefile
	scripts/mkversion
	scripts/mod/mk_elfconfig
	scripts/kconfig/conf
	scripts/mkcompile_h
	scripts/makelst
	scripts/Makefile.modpost
	scripts/Makefile.modinst
	scripts/Makefile.lib
	scripts/Makefile.host
	scripts/Makefile.clean
	scripts/Makefile.build
	scripts/Makefile
	scripts/Kbuild.include
	scripts/kallsyms
	scripts/genksyms/genksyms
	scripts/basic/fixdep
	scripts/extract-ikconfig
	scripts/conmakehash
	scripts/checkversion.pl
	scripts/checkincludes.pl
	scripts/checkconfig.pl
	scripts/bin2c
	scripts/gcc-version.sh

	.config
	.kernelrelease
	gcc_version.inc
"
for f in $KbuildFiles; do
	[ -e "$f" ] || continue
	[ -x "$f" ] && mode=755 || mode=644
	%__install -Dp -m$mode "$f" \
		%buildroot%_prefix/src/linux-%version-%flavour/"$f"
done

%__rm -f %buildroot%modules_dir/{build,source}
%__ln_s %_prefix/src/linux-%version-%flavour %buildroot%modules_dir/build

# install documentation
%if_enabled docs
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__cp -a Documentation/* %buildroot%_docdir/kernel-doc-%base_flavour-%version/
%__install -d %buildroot%_docdir/kernel-doc-%base_flavour-%version/scsi/
find %buildroot%_docdir/kernel-doc-%base_flavour-%version/DocBook \
	-maxdepth 1 -type f -not -name '*.html' -delete
%endif # if_enabled docs

%post
%post_kernel_image %kversion-%flavour-%krelease

%preun
%preun_kernel_image %kversion-%flavour-%krelease

%if_enabled oss_sound
%post -n kernel-modules-oss-%flavour
%post_kernel_modules %kversion-%flavour-%krelease

%postun -n kernel-modules-oss-%flavour
%postun_kernel_modules %kversion-%flavour-%krelease
%endif

%post -n kernel-headers-%flavour
%post_kernel_headers %kversion-%flavour-%krelease

%postun -n kernel-headers-%flavour
%postun_kernel_headers %kversion-%flavour-%krelease

%files
/boot/vmlinuz-%kversion-%flavour-%krelease
/boot/System.map-%kversion-%flavour-%krelease
/boot/config-%kversion-%flavour-%krelease
%modules_dir
%exclude %modules_dir/build

%if_enabled oss_sound
# OSS drivers
%exclude %modules_dir/kernel/sound/oss
%ifarch %ix86
%exclude %modules_dir/kernel/drivers/media/radio/miropcm20.ko
%exclude %modules_dir/kernel/drivers/media/radio/miropcm20-rds.ko
%endif
%exclude %modules_dir/kernel/drivers/usb/class/audio.ko
%exclude %modules_dir/kernel/drivers/usb/class/usb-midi.ko

%files -n kernel-modules-oss-%flavour
%modules_dir/kernel/sound/oss
%ifarch %ix86
%modules_dir/kernel/drivers/media/radio/miropcm20.ko
%modules_dir/kernel/drivers/media/radio/miropcm20-rds.ko
%endif
%modules_dir/kernel/drivers/usb/class/audio.ko
%modules_dir/kernel/drivers/usb/class/usb-midi.ko

# /oss_sound
%endif

%files -n kernel-headers-%flavour
%_prefix/include/linux-%version-%flavour

%files -n kernel-headers-modules-%flavour
%_prefix/src/linux-%version-%flavour
%modules_dir/build

%if_enabled docs
%files -n kernel-doc-%base_flavour
%doc %_docdir/kernel-doc-%base_flavour-%version
%endif

%changelog
* Tue Jul 18 2006 Denis Pynkin <d.pynkin@sam-solutions.net> 2.6.16-aw1
- Merged with patch 2.6.16.26 (Relax /proc fix a bit) 

* Thu Jul 06 2006 Denis Pynkin <d.pynkin@sam-solutions.net> 2.6.16-aw0
- Configuration changed for AW

* Sun Jun 18 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt7
- Patches updated up to 2.6.16.20.
- Moved kernel-fix-security to the start of patch list.
- Updated kernel-feat-net-ieee80211:
  + fix wrong value for 802.11a channel count
- Updated kernel-fix-acpi:
  + processor: work around oops on powernow-k8 unload
- Updated kernel-fix-core:
  + fix swsusp resume triggered from old-style initrd
  + cpuset: might sleep checking zones allowed fix
  + x86_64: add crashdump trigger points
  + x86_64: don't do syscall exit tracing twice
- Added kernel-fix-drivers-input:
  + psmouse: fix new device detection logic
- Updated kernel-fix-drivers-ieee1394:
  + ohci1394, sbp2: fix "scsi_add_device failed" with PL-3507 based devices
  + sbp2: backport read_capacity workaround for iPod
  + sbp2: fix check of return value of hpsb_allocate_and_register_addrspace
- Updated kernel-fix-drivers-net:
  + b44: initialize the chip earlier, so that changing the MAC address before
    the interface is up will work (bug #9672)
  + b44: check that the MAC address from EEPROM or user input is valid
  + b44: disable tx pause frame support by default due to hardware bug
  + b44: x86_64: check for bad dma address in 1GB DMA workaround
- Updated kernel-fix-drivers-pci:
  - removed broken VIA IRQ fixup patches
- Updated kernel-fix-drivers-scsi:
  + fix libata resume lockup on some machines
- Updated kernel-fix-fs:
  + tmpfs: time granularity fix for inode times going backwards
- Updated kernel-fix-security:
  + CVE-2006-1343: netfilter: fix small information leak in SO_ORIGINAL_DST
- Modified configuration:
  + enabled software suspend to disk (CONFIG_SOFTWARE_SUSPEND)
- Require mkinitrd >= 1:2.9.9-alt1 for software suspend support.

* Fri May 26 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt6
- Patches updated up to 2.6.16.18.
- Updated kernel-fix-security:
  + CVE-2006-1858: SCTP: respect the real chunk length when walking parameters
  + CVE-2006-1857: SCTP: validate the parameter length in HB-ACK chunk
  + CVE-2006-2444: netfilter: SNMP NAT: fix memory corruption

* Sat May 20 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt5
- Patches updated up to 2.6.16.16 + 2.6.16-stable queue.
- Updated kernel-fix-core:
  + make vm86 call audit_syscall_exit()
  + clean up broken asm in vm86 syscall audit code
  + remove cond_resched in gather_stats()
  + add migratepage address space op to shmem
  + page migration: fix fallback behavior for dirty pages
  + fix ptrace_attach()/ptrace_traceme()/de_thread() race
  + ptrace_attach: fix possible deadlock schenario with irqs
- Updated kernel-fix-drivers-block:
  + ub: fix oops in block_uevent()
  + block layer: limit request_fn recursion
- Updated kernel-fix-drivers-char:
  + tipar: fix oops when compiled into the kernel
- Updated kernel-fix-drivers-i2c:
  + scx200_acb: fix resource name use after free
- Updated kernel-fix-drivers-md:
  + md: avoid oops when attempting to fix read errors on raid10
- Updated kernel-fix-drivers-net:
  + via-rhine: zero pad short packets on Rhine I ethernet cards
  + tg3: fix ethtool always reporting port is TP
- Updated kernel-fix-drivers-pci:
  + PCI quirk: do not unhide Intel SMBus controller if ACPI suspend is enabled
    (unhiding SMBus kills thermal management after suspend on many laptops)
  + PCI quirk: run VIA IRQ fixup only for VIA southbridges
  + PCI quirk: fix the previous VIA IRQ fixup fix (add VIA 82C586 PCI IDs)
  + PCI ACPI: correctly allocate return buffers for _OSC calls
  + PCI quirk: add 'unhide_smbus' boot option to unhide SMBus controllers
    disabled by BIOS
- Updated kernel-fix-drivers-pcmcia:
  + cardman 40x0: fix udev device creation
- Updated kernel-fix-fs:
  + fix sys_flock() race which could result in double free
  + tmpfs: decrement i_nlink correctly in shmem_rmdir()
  + smbfs: fix slab corruption in samba error path
  + fix typo in compat_sys_ppoll()
- Updated kernel-fix-security:
  + CVE-2006-1527: netfilter: sctp conntrack: fix infinite loop
  + CVE-2006-1864: smbfs: fix chroot issue
  + CVE-2006-2272: SCTP: fix panic when receiving fragmented SCTP control
    chunks
  + CVE-2006-2271: SCTP: fix state table entries for chunks received in CLOSED
    state
  + CVE-2006-2275: SCTP: allow spillover of receive buffer to avoid deadlock
  + CVE-2006-2274: SCTP: prevent possible infinite recursion with multiple
    bundled DATA
  + CVE-2006-1860: fs/locks.c: fix lease_init
  + CVE-2006-0039: netfilter: fix do_add_counters race

* Sun Apr 30 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt4
- Patches updated up to 2.6.16.11 + 2.6.16-stable queue.
- Added kernel-feat-net-ieee80211: update IEEE 802.11 subsystem to version
  1.1.13 (required for newer version of Intel wireless drivers).
- Updated kernel-fix-core:
  + x86_64: pass -32 to the assembler when compiling the 32bit vsyscall pages
  + x86_64: fix a race in the free_iommu path
  + backport for_each_possible_cpu() into 2.6.16
  + x86/PAE: fix pte_clear for the >4GB RAM case
- Updated kernel-fix-drivers-char:
  + cs5535_gpio: call cdev_del() during module_exit
  + sonypi: correct detection of new ICH7-based laptops
- Updated kernel-fix-drivers-md:
  + dm snapshot: fix kcopyd destructor
  + dm: fix dm_suspend() cancellation
- Updated kernel-fix-drivers-media:
  + get_dvb_firmware: download nxt2002 firmware from new driver location
  + fix saa7129 support in saa7127 module for pvr350 tv out
  + cxusb-bluebird: power down corrupts frontend
- Updated kernel-fix-drivers-net:
  + e1000: update truesize with the length of the packet for packet split
- Updated kernel-fix-drivers-usb:
  + fix array overrun in drivers/usb/serial/option.c
- Updated kernel-fix-fs:
  + simplify /proc/devices and fix early termination regression
  + reiserfs: fix acl-related deadlock
  + LSM: add missing hook to do_compat_readv_writev()
- Updated kernel-fix-security:
  + CVE-2006-1863: cifs: don't allow a backslash in a path component
  + fix FP exception handling broken by the CVE-2006-1056 fix

* Sun Apr 23 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt3
- Patches updated up to 2.6.16.9 + 2.6.16-stable queue.
- Updated kernel-fix-core:
  + fix buddy list race that could lead to page lru list corruptions
  + RLIMIT_CPU: fix handling of a zero limit
  + fix suspend with traced tasks
  + fix non-leader exec under ptrace
  + ipc: fix access to unmapped vmalloc area in grow_ary()
  + apm: fix the "apm: set display: Interface not engaged" error on Armada
    laptops again
  + add more prevent_tail_call() to fix userspace register corruption
- Updated kernel-fix-drivers-block:
  + cciss: fix crash when running hpacucli
- Updated kernel-fix-drivers-char
  + efficeon-agp: add missing memory mask
  + ipmi: fix buffer overflow in BT code
- Updated kernel-fix-drivers-i2c:
  + i2c-i801: fix resume when PEC is used
  + m41t00: fix bitmasks when writing to chip
- Updated kernel-fix-drivers-ide:
  + alim15x3: fix ULI M1573 southbridge support
- Added kernel-fix-drivers-mtd:
  + MTD_NAND_SHARPSL and MTD_NAND_NANDSIM should be tristate's
- Updated kernel-fix-drivers-scsi:
  + 3w-xxxx: disable local IRQs around kmap_atomic() calls
  + 3w-9xxx: disable local IRQs around kmap_atomic() calls
- Updated kernel-fix-drivers-usb:
  + remove __init from usb_console_setup
- Updated kernel-fix-drivers-video:
  + fbdev: fix return error of fb_write
- Updated kernel-fix-fs:
  + fuse: fix oops in fuse_send_readpages()
  + fix block device symlink name for devices with a '/' in their name
  + ext3: fix missed mutex unlock in error path
  + xfs: fix utime(2) in the case that no times parameter was passed in
  + cifs: fix incorrect signature sent on SMB Read (Samba bug 3621, kernel.org
    bug 6147)
  + x86: don't allow tail-calls in sys_ftruncate[64]() to avoid userspace
    register corruption
  + x86: be careful about tailcall breakage for sys_open[at] too
  + fix file lookup without ref
- Updated kernel-fix-net:
  + atm: clip causes unregister hang
  + tcp: fix truesize underflow with TSO
  + ipv6: ensure to have hop-by-hop options in our header of sk_buff
  + ipv6: xfrm: don't use old copy of pointer after pskb_may_pull()
  + ipv6: xfrm: fix decoding session with preceding extension header(s)
- Updated kernel-fix-security:
  + CVE-2006-0744: x86_64: always call IRET in execve; when user could have
    changed RIP always force IRET
  + shmat: stop mprotect from giving write permission to a readonly attachment
  + CVE-2006-1524: check file and mmap protections for MADV_REMOVE
  + CVE-2006-1525: ipv4: ip_route_input panic fix
  + CVE-2006-1056: i386/x86-64: fix x87 information leak between processes
  + selinux: fix MLS compatibility off-by-one bug

* Wed Apr 12 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt2
- Patches updated up to 2.6.16.4.
- Updated kernel-fix-core:
  + fix wrong error path in dup_fd() leading to oopses in RCU
  + cpufreq: mark longhaul driver as broken
  + cpufreq: fix the p4-clockmod N60 errata workaround
  + fix module refcount leak in __set_personality()
  + fix NULL pointer dereference in node_read_numastat()
- Updated kernel-fix-drivers-char:
  + isicom must select FW_LOADER
  + tlclk: fix sysfs permissions
- Added kernel-fix-drivers-ieee1394:
  + sbp2: fix spinlock recursion
- Updated kernel-fix-drivers-media:
  + saa7134: fix oops with disable_ir=1
- Updated kernel-fix-drivers-net:
  + PCMCIA_SPECTRUM must select FW_LOADER
  + ipw2200: fix an array overrun
  + AIRO and AIRO_CS must select CRYPTO
  + hostap: fix EAPOL frame encryption
  + sky2: fix oops on dual port cards
  + PPP MPPE: do not accept unsupported MPPE options
- Added kernel-fix-drivers-pcmcia:
  + pcmcia: permit single-character-identifiers
- Updated kernel-fix-drivers-usb:
  + EHCI full speed ISO bugfixes
  + usbcore: usb_set_configuration oops (NULL ptr dereference)
  + isd200: limit to BLK_DEV_IDE
- Updated kernel-fix-drivers-video:
  + fbcon: fix big-endian bogosity in slow_imageblit()
- Updated kernel-fix-fs:
  + knfsd: correct reserved reply space for read requests
  + kdump proc vmcore size overflow fix
- Updated kernel-fix-net:
  + {ip,nf}_conntrack_netlink: fix expectation notifier unregistration
  + fib_trie.c node freeing fix
  + netfilter: fix fragmentation issues with bridge netfilter
  + fix hotplug race during device registration
- Updated kernel-fix-security:
  + CVE-2006-1055: sysfs: zero terminate sysfs write buffers
  + CVE-2006-1522: keys: fix oops when adding key to non-keyring
  + CVE-2006-1523: __group_complete_signal: remove bogus BUG_ON

* Thu Mar 30 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.16-alt1
- 2.6.16 (patches from 2.6.16.1 included).
- Added more files to kernel-headers-modules-%%flavour subpackage:
  + arch/%%base_arch/Makefile.cpu
  + scripts/mkmakefile
  + .kernelrelease
- Added kernel-fix-security-altsec - hardening patch for Linux 2.6.
- Updated kernel-feat-drivers-net-sk98lin:
  + updated sk98lin driver to 8.31
  + added patch to fix compilation with 2.6.16
- Updated kernel-fix-build:
  + fix kbuild compatibility with make-3.81rc1
  + fix <linux/rtc.h> changes which broke strace builds
- Updated kernel-fix-core:
  + sysfs: sysfs_remove_dir() needs to invalidate the dentry (fixes USB cdc-acm
    oops on disconnect)
  + firmware: fix BUG: in fw_realloc_buffer
  + fix get_cpu_sysdev() parameter type
  + sysfs: fix a kobject leak in sysfs_add_link on the error path
  + fix scheduler deadlock
  + DMI: fix DMI onboard device discovery
  + speedstep-smi: fix assembly bug in speedstep_smi_ownership
  + unshare: error if passed unsupported flags
- Updated kernel-fix-drivers-block:
  + cciss: fix use-after-free in cciss_init_one
- Updated kernel-fix-drivers-char:
  + tlclk: fix handling of device major
  + agpgart: add ATI RS350 support
  + agpgart: fix wrong PCI ID for ALI M1695 AGP bridge
- Updated kernel-fix-drivers-i2c:
  + i2c-piix4: add Broadcom HT-1000 support
  + i2c-ixp4xx: add hwmon class
- Updated kernel-fix-drivers-md:
  + dm: bio split bvec fix
  + raid1: fix bug: BIO_RW_BARRIER requests to md/raid1 hang
- Updated kernel-fix-drivers-media:
  + V4L/DVB: fix Samsung NTSC tuner frequency ranges
  + VIDEO_DECODER must select FW_LOADER
- Updated kernel-fix-drivers-scsi:
  + sata_mv: fix irq port status usage
  + sata_mv: fix off by one bug in processing of the EDMA response queue
- Updated kernel-fix-drivers-usb:
  + irda-usb: fix use-after-free bug in irda_usb_receive()
- Updated kernel-fix-drivers-video:
  + i810fb_cursor(): use GFP_ATOMIC
- Updated kernel-fix-fs:
  + fix duplicated line in /proc/devices
  + xfs: avoid writeout of clean data
  + v9fs: assign dentry ops to negative dentries
- Updated kernel-fix-net:
  + ensure device name passed to SO_BINDTODEVICE is NULL terminated
- Updated kernel-fix-security:
  + CVE-2006-1242: TCP: do not use inet->id of global tcp_socket when sending
    RST
- Updated kernel-fix-acpi, kernel-fix-core, kernel-fix-drivers-block,
  kernel-fix-drivers-char, kernel-fix-drivers-i2c, kernel-fix-drivers-ide,
  kernel-fix-drivers-media, kernel-fix-drivers-net, kernel-fix-drivers-scsi,
  kernel-fix-drivers-usb, kernel-fix-fs, kernel-fix-net, kernel-fix-security:
  - disabled obsolete patches when applying to kernel 2.6.16
- Removed kernel-fix-core-skbuff, kernel-fix-drivers-hwmon,
  kernel-fix-drivers-input, kernel-fix-drivers-pcmcia,
  kernel-feat-net-ieee80211, kernel-feat-net-ppp-mppe (obsolete patches)
- Important configuration changes:
  + i586: enabled CONFIG_REGPARM
  + changed default IO scheduler to CFQ
  + enabled traffic control actions support (CONFIG_NET_CLS_ACT)
  + usb-storage: enabled ub driver in addition to usb-storage, enabled libusual
    module to select between ub and usb-storage
  + enabled kernel-fix-security-altsec features:
    + CONFIG_ALT_SECURE_PROC: tighten permissions for some things in /proc
      (similar to the Openwall patch for kernels 2.4.x)
    + CONFIG_ALT_SECURE_SHM: immediately destroy unused SysV shared memory
      segments (configurable through the kernel.shm_destroy_unused sysctl)

* Thu Feb 09 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.14-alt5
- Updated kernel-fix-drivers-ide:
  + via82cxxx: add VIA VT8251 IDE controller support
- Added kernel-fix-drivers-input:
  + mousedev: fix memory leak
  + iforce: fix detection of USB devices
- Updated kernel-fix-drivers-scsi:
  + ahci: add VIA VT8251 SATA controller support
- Updated kernel-fix-fs:
  + fix NFS inode leak when d_instantiate_unique finds aliased dentry
- Updated kernel-fix-net:
  + ppp: fix hardware RX checksum handling
- Updated kernel-fix-security:
  + CVE-2006-0095: dm-crypt: zero key before freeing it
  + seclvl: do not crash on settime() with a NULL timeval
  + fix keyctl usage of strnlen_user()

* Tue Feb 07 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.14-alt4
- Updated kernel-fix-core:
  + fix setting irq affinity with MSI enabled
- Updated kernel-fix-drivers-scsi:
  + i2o_scsi: fix oops on command abort
- Updated kernel-fix-fs:
  + ufs: fix oops on mount
  + reiserfs: fix mount options parsing
- Updated kernel-fix-net:
  + ebtables: don't match tcp/udp source/destination port for IP fragments
  + netlink: fix oops on socket creation failure
  + fix /sys/class/net/<if>/wireless without dev->get_wireless_stats
  + make second arg to skb_reserve() signed (fixes PPP on 64-bit archs)
- Updated kernel-fix-security:
  + moxa: require CAP_SYS_RAWIO for firmware loading ioctls
  + CVE-2006-0036: netfilter: fix crash in ip_nat_pptp
  + CVE-2006-0037: netfilter: fix another crash in ip_nat_pptp
  + CVE-2005-3356: fix refcounting on failure exits in sys_mq_open()
  + CVE-2006-0454: icmp: fix extra dst release when ip_options_echo() fails

* Fri Jan 20 2006 LAKostis <lakostis at altlinux.ru> 2.6.14-alt3.1
- add missing bt{848,cx-risc} headers for lirc compiling.

* Sat Jan 07 2006 Sergey Vlasov <vsu@altlinux.ru> 2.6.14-alt3
- Updated kernel-fix-core:
  + add try_to_freeze to kauditd to fix suspend failure
  + kernel/params.c: fix sysfs access with CONFIG_MODULES=n
- Updated kernel-fix-drivers-block:
  + cciss: bug fix for hpacucli
  + cciss: bug fix for BIG_PASS_THRU
- Updated kernel-fix-drivers-char:
  + agpgart: fix serverworks TLB flush
  + i8k: fix /proc reporting of blank service tags
- Updated kernel-fix-drivers-ide:
  + ide-floppy: fix software eject with LS-120 drive
- Added kernel-fix-drivers-media:
  + dvb: BUDGET CI card depends on STV0297 demodulator
  + dvb: fix tuner init for Pinnacle PCTV Stereo
  + dvb: fix analog NTSC for Thomson DTT 761X hybrid tuner (pcHDTV 3000,
    FusionHDTV3 Gold-T)
  + dvb: dst: fix possible buffer overflow
- Updated kernel-fix-drivers-net:
  + sungem: gem_remove_one mustn't be __devexit
- Added kernel-fix-drivers-pcmcia:
  + i82365: release all resources if no devices are found
- Updated kernel-fix-drivers-scsi:
  + libata: separate controller-wide spinlock from Scsi_Host lock
  + dpt_i2o fix for deadlock condition
  + fix transfer direction in sd (kernel panic when ejecting iPod)
  + fix transfer direction in scsi_lib and st
- Updated kernel-fix-drivers-usb:
  + adapt microtek driver to new scsi features
  + usbhid: fix oops when connecting simulation devices generating unknown
    simulation events
  + pl2303: add IDs for Siemens SX1 and x75 mobiles
  + pl2303: fix data length check in pl2303_update_line_status
- Updated kernel-fix-fs:
  + fix listxattr() for generic security attributes
  + ufs: inode->i_sem is not released in error path
- Updated kernel-fix-net:
  + fix processing of fib_lookup netlink messages
  + bonding: fix feature consolidation
  + bridge: recompute features when adding a new device
  + netfilter: fix CTA_PROTO_NUM attribute size in ctnetlink
  + netfilter: fix unbalanced read_unlock_bh in ctnetlink
  + ip_gre: fix hardware checksum modification
  + vlan: fix hardware rx csum errors
  + netfilter: fix NAT init order
  + netfilter: fix incorrect dependency for IP6_NF_TARGET_NFQUEUE
  + rtnetlink: fix RTNLGRP definitions in rtnetlink.h
  + bridge-nf: fix ipv6 length check
  + ipv6: fix route lifetime
  + ipsec: perform SA switchover immediately
  + IEEE80211_CRYPT_TKIP depends on NET_RADIO
- Updated kernel-fix-security:
  + updated CVE-2005-3257 fix patch:
    - require CAP_SYS_TTY_CONFIG for KDSKBENT in addition to KDSKBSENT
    - allow normal users to read current settings
  + CVE-2005-3623: nfsd: do not allow setting ACLs on readonly mounted NFS
    filesystems
  + CVE-2005-4605: insanity avoidance in /proc
  + sysctl: don't overflow the user-supplied buffer with '\0'
  + sysctl: make sure to terminate strings with a NUL

* Sun Dec 04 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.14-alt2
- Restored x86_64 support; updated kernel config for x86_64.
- Updated kernel-fix-acpi:
  + fix HP nx8220 boot hang regression due to change in acpi_bus_find_driver()
  + prefer _CST over FADT for C-state capabilities (as written in the ACPI
    standard)
  + support FADT P_LVL2_UP flag (C2 is valid for UP only)
  + properly detect pmtimer on ASUS A8V
  + fix null pointer deref in video/lcd/brightness
  + fix boot hang on HT boxes with broken BIOS reporting wrong ACPI IDs
  + allow return to active cooling mode once passive mode is entered
- Updated kernel-fix-drivers-ide:
  + via82cxxx: add VT6410 controller support
- Updated kernel-fix-fs:
  + xfs: fix umount/xfslogd deadlock
- Updated kernel-fix-security:
  + CVE-2005-3257: require root privileges for loading key mappings
  + CVE-2005-3857: remove time_out_leases() printk that's easily triggered by
    users
  + CVE-2005-3808: fix 32bit integer overflow in invalidate_inode_pages2()

* Wed Nov 30 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.14-alt1
- 2.6.14.
- Temporarily removed x86_64 support (to be restored by arch maintainers).
- Removed kernel-fix-drivers-ieee1394, kernel-fix-drivers-input,
  kernel-fix-drivers-media, kernel-feat-drivers-input (obsolete).
- Removed kernel-feat-drivers-video-splash (does not work currently).
- Removed kernel-feat-drivers-lirc (the patch is unmaintained, some drivers no
  longer compile at all, others refer to symbols which no longer exist in the
  kernel).
- Added kernel-fix-drivers-hwmon - fixes to hardware monitoring drivers:
  + it87: fix missing fan div init
  + lm78: fix VID conversion
  + w83627hf: fix missing boundary check when setting in0 limits
- Added kernel-feat-net-ieee80211 - IEEE 802.11 subsystem update (needed for
  newer versions of ipw2x00 drivers; cannot be built separately, because now
  there are some in-kernel drivers which use it).
- Added drivers/md/dm*.h headers to kernel-headers-modules-%%flavour (#8443).
- Added drivers/media/video/bttv.h, drivers/media/video/bttvp.h to
  kernel-headers-modules-%%flavour (needed for separate compilation of lirc
  modules).
- Updated kernel-fix-acpi:
  + updated the dsdt-initrd patch to version 0.7e for kernel 2.6.14
  + fix oops on processor module unload when ACPI is disabled
- Updated kernel-fix-build:
  + fix Kconfig dependencies (selecting NFSD_V4 forced CRYPTO_MD5 to be
    builtin, even if NFSD was modular)
- Updated kernel-fix-core:
  + fix de_thread() vs send_group_sigqueue() race
  + fix ptrace self-attach rule
  + fix signal->live leak in copy_process()
  + ptrace: don't auto-reap traced children
  + x86_64/i386: Compute correct MTRR mask on early Noconas
  + fix crash when ptrace poking hugepage areas
- Updated kernel-fix-drivers-block:
  + fix oops on suspend after on-the-fly switch to anticipatory i/o scheduler
  + pktcdvd: fix possible oops in pkt_count_states() due to array overrun
- Updated kernel-fix-drivers-char:
  + fix soft lockup with ALSA rtc-timer due to the wrong irq handling in
    rtc_control()
- Updated kernel-fix-drivers-net:
  + airo.c/airo_cs.c: correct prototypes
  + prism54: fix frame length setting bug which might result in information
    leak
  + drivers/isdn/hardware/eicon/os_4bri.c: correct the xdiLoadFile() signature
  + generic HDLC WAN drivers: disable netif_carrier_off()
  + infiniband: fix a use-after-free
- Updated kernel-fix-drivers-scsi:
  + updated patch for old megaraid driver:
    + removed controllers which are supported by the new driver (megaraid_mbox)
      from the table of supported devices
    + changed PCI driver name to megaraid_legacy to avoid conflict with the
      newer driver
  + dpt_i2o: fix use-after-free
  + i2o_pci: fix use-after-free
  + fix SCSI_SATA_INTEL_COMBINED setting with modular IDE
  + add boot option to control Intel combined mode behavior (to allow DMA in
    combined mode configs)
- Updated kernel-fix-drivers-usb:
  + USB: always export interface information for modalias
- Updated kernel-fix-fs:
  + VFS: fix memory leak with file leases
  + fix XFS_QUOTA for modular XFS
- Updated kernel-fix-net:
  + fix zero-size datagram reception
  + ipvs: fix connection leak if expire_nodest_conn=1
  + tcp: fix too large BIC max increment
  + ctnetlink: check if protoinfo is present
  + ctnetlink: fix oops when no ICMP ID info in message
  + ipv6: fix calculation of AH length during filling ancillary data
  + ipv6: fix memory management error during setting up new advapi sockopts
  + ipv6: fix sending extension headers before and including routing header
  + ip_conntrack: fix ftp/irc/tftp helpers on ports >= 32768
  + ip_conntrack TCP: Accept SYN+PUSH like SYN
  + NAT: fix module refcount dropping too far
  + nf_queue: fix Ooops when no queue handler registered
  + PPTP helper: fix endianness bug in GRE key / CallID NAT
  + PPTP helper: fix PNS-PAC expectation call id
  + fix refcount leak of proto when ctnetlink dumping tuple
- Updated kernel-fix-security:
  + fix syctls unregistration oops (CVE-2005-2709)

* Sun Aug 14 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.12-alt4
- Updated kernel-fix-acpi:
  - removed suspend-setup-leave patch (#6785, #7539)
- Updated kernel-fix-core:
  + do not BUG() when module per-cpu alignment cannot be met
  + fix powernow oops on dual-core Athlon
  + clear the returned argument in sys_get_thread_area()
  + check if mode < 0 in sys_set_mempolicy()
  + x86_64: fix memleak from malicious 32bit elf program
  + x86_64: fixing smpboot timing problem
  + x86_64: fix SRAT for non dual-core AMD systems
- Updated kernel-fix-drivers-char:
  + rocket: fix ldisc ref count handling
  + moxa: fix tty driver name which was conflicting with the BSD-style pty
    driver, therefore some ports were inaccessible when using udev
- Updated kernel-fix-drivers-scsi:
  + qla2xxx: correct handling of fc_remote_port_add() failure case
- Updated kernel-fix-fs:
  + fix BIO cloning bug which could result in data corruption with some MD
    setups
  + check input buffer size in zisofs
- Updated kernel-fix-net:
  + fix early vlan adding leads to not functional device
  + xfrm: fix possible overflow of sock->sk_policy
  + fix potential memory corruption in NAT code
  + fix deadlock in ip6_queue
  + wait until all references to ip_conntrack_untracked are dropped on unload
  + fix signedness issues in net/core/filter.c
- Updated kernel-fix-security:
  + fix keyring handling bugs (CAN-2005-2098, CAN-2005-2099)
- Updated kernel-feat-drivers-net-sk98lin:
  + version 8.23
- Rebuild with new kernel-feat-fs-squashfs.

* Mon Jul 25 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.12-alt3
- Fixed kernel-fix-core-skbuff so that it does nothing for 32-bit architectures
  and enabled it for all architectures to avoid arch-specific BuildRequires.
- Updated kernel-fix-acpi:
  + if ACPI doesn't find an irq listed, don't accept 0 as a valid PCI irq
  + fix PNPACPI resource parser (#7392)
- Updated kernel-fix-drivers-char:
  + fix tpm driver initialization which was messing up other devices
  + add missing NULL checks in tty ioctl code
- Updated kernel-fix-drivers-media:
  + cx88: set hue offset to 128 to correct behavior in cx88 cards
- Updated kernel-fix-drivers-net:
  + fix locking in the shaper driver
- Updated kernel-fix-fs:
  + fix locking in __unregister_chrdev_region()
- Updated kernel-fix-net:
  + revert the nf_reset change completely (previous fix was not enough); drop
    conntrack references manually before packets are queued to packet sockets
- Added kernel-fix-drivers-input:
  + fix problem with trackpoint attached to synaptics passthrough port

* Thu Jul 14 2005 Anton D. Kachalov <mouse@altlinux.org> 2.6.12-alt2
- Per-arch configuration
- Added kernel-fix-core-skbuff for x86_64 only

* Sat Jul 02 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.12-alt1
- 2.6.12.
- Updated kernel-fix-build, kernel-fix-core, kernel-fix-drivers-char,
  kernel-fix-drivers-ide, kernel-fix-drivers-media, kernel-fix-drivers-net,
  kernel-fix-drivers-pci, kernel-fix-drivers-scsi, kernel-fix-drivers-usb,
  kernel-fix-drivers-video, kernel-fix-fs, kernel-fix-net, kernel-fix-security:
  - removed obsolete patches
- Updated kernel-fix-acpi:
  + updated acpi-attrs and suspend-setup-leave patches for 2.6.12
  + call acpi_register_gsi() even for default PCI interrupt assignment (needed
    to set PCI interrupts to level/low properly)
- Updated kernel-fix-core:
  + round size in remap_pfn_range() up to a page boundary
  + add "memory" clobbers to string.h functions to avoid memory access
    reordering by gcc
- Updated kernel-fix-drivers-media:
  + updated Manli and BeholdTV remote control support patch for 2.6.12
- Updated kernel-fix-drivers-net:
  + e1000: fix spinlock bug
- Updated kernel-fix-drivers-pci:
  + fix typo in drv->driver.shutdown setting for PCI drivers that might result
    in not setting drv->driver.owner
- Updated kernel-fix-drivers-scsi:
  + fix qla2xxx initialization problems
- Updated kernel-fix-drivers-usb:
  + updated old_scheme_first patch for 2.6.12
- Updated kernel-fix-net:
  + fix connection tracking on bridges
  + fix socket hashing bugs in netlink
- Updated kernel-fix-security:
  + CAN-2005-1913
- Updated kernel-feat-drivers-input:
  + updated trackpoint support patch:
    - warning: module parameters for trackpoint device configuration are no
      longer available - use sysfs for configuration;
    - support for scroll emulation in the driver was removed - use the
      appropriate Xorg options
- Updated kernel-feat-drivers-lirc, kernel-feat-drivers-sk98lin:
  + fix compilation with 2.6.12
- Updated kernel-feat-drivers-video-splash:
  + updated splash patch for kernel 2.6.12

* Mon Jun 13 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt11
- Updated kernel-fix-core:
  + fix get_unmapped_area() sanity tests
  + fix try_to_unmap_cluster() passing out-of-bounds pte to pte_unmap()
- Updated kernel-fix-drivers-char:
  + fix mxser receive problem (#6615)
- Updated kernel-fix-drivers-media:
  + bttv: make video capture work on Leadtek WinFast VC100 XP cards
  + saa7134: add support for remote control as used with Manli MuchTV
    M-TV00[12] boards; add BeholdTV 401 and BeholdTV 403 FM card names to the
    Manli entries (#6917)
  + bttv: fix oops on i2c registration failure
- Updated kernel-fix-fs:
  + ext3: fix possible false assertion failure in log_do_checkpoint()
  + hfs, hfsplus: fix leaks and oops in hfsplus
- Updated kernel-fix-net:
  + bridge: avoid poisoning of the bridge forwarding table by frames that have
    been dropped by filtering
  + netem: avoid infinite loop in qdisc_run() when using duplication
  + fix deadlock with ip_queue and tcp local input path
- Modified configuration:
  + disabled CONFIG_PREEMPT (with the default scheduler this options causes
    significant slowdown especially noticeable during boot)
  + disabled CONFIG_ACPI_DEBUG (workaround for #6304)
  + enabled CONFIG_LOGO_LINUX_CLUT224 (#6975)
  + enabled CONFIG_LOGO_LINUX_MONO (just in case)
- Moved OSS modules for USB audio devices (audio and usb-midi) to the
  kernel-modules-oss-%%flavour subpackage (the snd-usb-audio module from ALSA
  is preferred).

* Sun May 15 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt10
- Updated kernel-fix-security:
  + fix user pointer validation in raw and pktcdvd drivers

* Fri May 13 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt9
- Updated kernel-fix-acpi:
  + show some ACPI device attributes in sysfs (currently hardware_id,
    compatible_ids, bus_address, unique_id)
- Updated kernel-fix-core:
  + remove bogus BUG() in kernel/exit.c
  + fix driver_detach in case the release handler itself calls
    device_release_driver() for the next device (could cause hangs with some
    USB drivers like cdc-acm which bind to more than one interface)
- Updated kernel-fix-drivers-net:
  + 3c59x: only put the device into D3 when we're actually using WOL (some
    devices have trouble with D3 on warm boot)
- Added kernel-fix-drivers-scsi:
  + aacraid: fix oops on management device open for nonexistent controller
  + fix queue lock allocation for SCSI devices (fixes problems with hot
    unplugging, especially with the CFQ scheduler)
    https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=155472
  +  require CAP_ADMIN for SG_IO to tape drives (sending SCSI commands to the
    drive behind the back of the st driver may cause the device state to be
    inconsistent with the internal driver state and cause problems)
  + enable both old and new megaraid drivers (the new megaraid_mbox driver does
    not support some devices which are supported by the old driver)
  + blacklist some broken SCSI scanners which respond to all LUNs
- Updated kernel-fix-drivers-usb:
  + fix bug in visor driver with throttle/unthrottle causing oopses
- Added kernel-fix-drivers-video:
  + fix bad PCI driver name in intelfb
  + fix oops in intelfb due to __initdata marking of module parameters
- Updated kernel-fix-fs:
  + fix race between ext3 make block reservation and reservation window discard
- Updated kernel-fix-net:
  + ebtables: fix smp race under heavy load
  + rose: verify ndigis in rose_rt_ioctl()
- Removed kernel-feat-drivers-drm (switched from in-kernel DRM drivers to the
  DRM CVS).
- Modified configuration:
  + enabled old megaraid driver in addition to the new one
  + disabled intel-mch-agp (it contains a copy of the intel-agp code for Intel
    82865 and 82875 chips intended for the x86_64 architecture; these chips are
    supported by the intel-agp module on i386)
  + disabled DRM support for buildind external DRM modules from DRI CVS;
    removed corresponding Provides from the package
- Reverted kernel-headers-%%flavour and kernel-headers-modules-%%flavour layout
  modification from 2.6.11-alt7 (causes problems when upgrading old packages).

* Wed May 11 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt8
- Updated kernel-fix-security:
  + fix ELF core dump issue (CAN-2005-1263)

* Tue May 10 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt7
- Added kernel-feat-drivers-net-sk98lin:
  + updated sk98lin driver to 8.16 from vendor
- Updated kernel-fix-acpi:
  + call ACPI suspend preparation methods in proper places with respect to PCI
    devices suspend/resume (#6785)
- Updated kernel-fix-core:
  + make rwsems use interrupt disabling spinlocks (fixes deadlock in
    dio_complete())
  + fix syscall table for UML
  + fix SMP crash in security/keys/key.c
- Added kernel-fix-drivers-i2c:
  + fix oops in the eeprom driver
  + fix sysfs permissions in it87 and via686a drivers (could cause oops if
    write is attempted)
  + fix multiple bugs in i2c-ali1563 driver
- Updated kernel-fix-drivers-media:
  + fix freeze on loading bttv in some configurations
- Updated kernel-fix-drivers-net:
  + fix irda-usb "badness" problem and sysfs support
- Updated kernel-fix-drivers-usb:
  + enable "old_scheme_first" and "use_both_schemes" parameters of usbcore by
    default (#6728)
- Updated kernel-fix-fs:
  + fix race in jbd code which could give oopses
- Updated kernel-fix-net:
  + fix deadlock in IPsec when sending ICMP "fragmentation needed" packet
  + fix binary search in the BIC congestion control algorithm
- Modified configuration:
  + enlarged kernel message buffer to 64 KB (#6366)
  + disabled software suspend support (does not work with modular drivers)
  + disabled buggy MTD drivers (#5994)
  + enabled NAPI support in starfire, r8169, ixgb, s2io drivers
  + enabled ISDN4Linux support
  + enabled OSS sound drivers (#6521)
  + disabled HID Boot Protocol drivers (usbkbd, usbmouse)
  + enabled EFI partition table support
- Build OSS sound drivers as a separate module package
  (kernel-modules-oss-%%flavour) (#6521).
- Fixed kernel-headers-%%flavour file list (some headers were missing).
- Fixed passing of config file to the kernel build system.
- Moved kernel-headers-%%flavour files to /usr/src/linux-%version-%flavour,
  leaving a symlink in /usr/include (fixes problems with third-party modules
  which don't like symlinks in the kernel source tree).
- Spec file cleanup, rewritten package descriptions.

* Tue Mar 29 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt6
- Updated kernel-fix-security:
  + fixed isofs corrupted filesystem handling (CAN-2005-0815)
  + fixed bluetooth range checking bug (CAN-2005-0750)
  + fixed ext2 information leak (CAN-2005-0400)
  + fixed binfmt_elf DoS (CAN-2005-0749)
- Updated kernel-fix-core:
  + fixed tasklist locking bug which caused hangs instead of reboot on SMP
- Updated kernel-fix-drivers-net:
  + fixed missing free_irq in error path in amd8111e and via-rhine drivers
  + fixed check for underflow in the tun driver
  + fixed kernel panic on receive in the hd6457x driver
- Updated kernel-fix-net:
  + fixed deadlock in NetROM
  + fixed crash when reading /proc/net/route
  + fixed bug in IPSEC support (__xfrm_find_acq_byseq)
- Fixed passing config file to the kernel build system (replacing defconfig was
  a broken way which worked before for some unknown reason).
- Removed hack which copied .config back to source.

* Wed Mar 16 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt5
- Updated kernel-fix-security:
  + fix ppp_async issue (CAN-2005-0384)
  + fix information leak through get_task_comm()

* Mon Mar 14 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.11-alt4
- 2.6.11 (really kernel-fix-* packages contain relevant patches from 2.6.11.3).
- Updated kernel-fix-security:
  + epoll: return proper error on overflow condition
- Updated kernel-fix-acpi, kernel-fix-core, kernel-fix-drivers-block,
  kernel-fix-drivers-md, kernel-fix-drivers-sound:
  - removed obsolete patches
- Updated kernel-fix-build:
  + fix "make htmldocs" failure
- Updated kernel-fix-drivers-ide:
  + fix no_lba48_dma flag handling in ide-disk (fixes DMA timeouts on old
    ALI15x3 controllers with a large disk)
- Updated kernel-fix-drivers-input:
  + make ACPI detection of i8042 controllers ia64-only (many x86 PCs have
    broken BIOS tables)
- Updated kernel-fix-drivers-net:
  + fix receive descriptor length setting in r8169
  + fix sis900 oops with preempt/SMP
  + fix via-rhine oops on shutdown with old chips without WOL support
- Updated kernel-fix-drivers-pci:
  + fix double free in the pciehp module
- Updated kernel-fix-drivers-usb:
  + fix cdc-acm oopses on disconnect
- Updated kernel-fix-fs:
  + fix stat for device nodes on cramfs
- Updated kernel-fix-net:
  + export tcp_timer_bug_msg for modular ipv6 build
- Updated kernel-feat-drivers-input:
  + updated trackpoint patch
  - removed alps patch (included in 2.6.11)
- Updated kernel-feat-drivers-video-splash:
  + new bootsplash patch for 2.6.11
- Added kernel-fix-drivers-char:
  + fix bug in drm setversion ioctl which could crash the X server
  + fix chip type for Radeon Yi ES1000 RN50
- Added kernel-fix-drivers-media:
  + fix saa7110 oops on modprobe
  + fix i2c message flags in video drivers
- Added kernel-feat-drivers-drm:
  + add VIA Unichrome driver (version 2.3.3)
- Removed kernel-fix-drivers-atm, kernel-fix-drivers-i2c,
  kernel-fix-drivers-serial, kernel-fix-drivers-parport (obsolete for 2.6.11).
- Modified configuration:
  + enabled all DRM modules (DRM sources from xorg-x11 6.8.2 no longer compile
    with kernel 2.6.11, but modules shipped with the kernel are new enough)
- Added Provides: kernel-modules-drm-%%flavour for compatibility.

* Wed Feb 09 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.10-alt3
- Build with gcc-3.4.
- Added kernel-fix-drivers-atm, kernel-fix-drivers-block,
  kernel-fix-drivers-i2c, kernel-fix-drivers-input, kernel-fix-drivers-md,
  kernel-fix-drivers-pci, kernel-fix-drivers-serial; updated kernel-fix-acpi,
  kernel-fix-core, kernel-fix-drivers-char, kernel-fix-drivers-ide,
  kernel-fix-drivers-scsi, kernel-fix-drivers-sound, kernel-fix-drivers-usb:
    + sync with 2.6.10-as3 patchset
- Modified configuration:
  + moved IDE support to modules
  + moved ext2 filesystem support to modules
  + disabled ALSA drivers (in-kernel version is too old, use separate
    kernel-modules-alsa-* packages which are updated)
- Changed /lib/modules/%%version-%%flavour-%%krelease/build symlink to point to
  %%_usrsrc/linux-%%version-%%flavour/ and moved it to the
  kernel-headers-modules-%%flavour subpackage.
- Added version to Provides: kernel-headers (#5872).
- Updated kernel-fix-drivers-ide:
  + added patch to fix endless partition rescan on PCMCIA flash (#5853).

* Sat Jan 08 2005 Sergey Vlasov <vsu@altlinux.ru> 2.6.10-alt2
- Removed broken symlink /lib/modules/%%version-%%flavour-%%krelease/source.
- Updated kernel-fix-security:
  + fix uselib() issue (CAN-2004-1235)
  + fix expand_stack issue (CAN-2005-0001)
  + fix integer signedness issues in moxa, random, scsi drivers
  + fix RLIMIT_MEMLOCK enforcement

* Wed Dec 29 2004 Sergey Vlasov <vsu@altlinux.ru> 2.6.10-alt1
- 2.6.10
- Added ccache support (was lost because of CC=gcc3.3 in the kernel
  makefile).
- Updated kernel-fix-build, kernel-fix-drivers-net, kernel-fix-net,
  kernel-feat-drivers-pktcdvd:
  - removed obsolete patches
- Updated kernel-fix-drivers-parport:
  + fixed parport_pc module parameters
- Updated kernel-feat-drivers-video-splash:
  + new bootsplash patch for 2.6.10
- Updated kernel-feat-net-ppp-mppe:
  + updated patch to version 1.2 (fixes CryptoAPI-related bug)
- Added kernel-fix-drivers-ieee1394:
  + remove broken MODULE_ALIAS_CHARDEV entries from ieee1394 modules (#3873)
- Removed kernel-fix-drivers-serial (obsolete).
- Modified configuration:
  + CONFIG_EDD is not set (causes boot problems, #5511)
  + CONFIG_APM_IGNORE_USER_SUSPEND is not set (apparently this option was set
    accidentally a long time ago and then forgotten)
  + CONFIG_GEN_RTC is not set (conflicts with the real RTC support)
  + CONFIG_FB_RADEON_OLD is not set (conflicts with the new radeonfb driver)
  + CONFIG_USB_DYNAMIC_MINORS is not set (#5484)
  + lots of new drivers enabled (too many to list here)

* Thu Oct 28 2004 Anton Farygin <rider@altlinux.ru> 2.6.9-alt11
- fixed iptables
- fixed kernel-headers for using with userspace programms (#5409)
- added kernel-feat-evms-nodm patch
- ppp fixed: terminate connection on hangup

* Wed Oct 20 2004 Anton Farygin <rider@altlinux.ru> 2.6.9-alt10
- new version
- enabled swsusp
- enabled preempt

* Wed Aug 18 2004 Sergey Vlasov <vsu@altlinux.ru> 2.6.8-alt9
- Added missing scripts/gcc-version.sh to kernel-headers-modules.
- Removed libkconfig.so shared library to avoid extra dependencies in packages.

* Mon Aug 16 2004 Anton Farygin <rider@altlinux.ru> 2.6.8-alt8
- 2.6.8
- added patch for fix typo in nfs code (2.6.8.1)
- updated acpi subsystem to last stable release (20040717)
- updated bootsplash

* Thu Aug 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt8
- Updated kernel-fix-security:
    + fix ppos races (CAN-2004-0415)

* Thu Jun 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.7-alt7
- 2.6.7
- updated bootsplash patch
- added kernel-fix-drivers-net:
  + 2.6_50_eql-check-null.patch: add NULL checks to the eql driver
  + 2.6_51_airo-proc-fix.patch: fix airo /proc write breakage
- added kernel-fix-drivers-usb:
  + 2.6_51_phidgetservo-fixes.patch: fix use of freed memory in PhidgetServo
    driver
  + 2.6_52_storage-jumpshot-fix.patch: fix size reporting in the Lexar Jumpshot
    CF driver; avoid "unneeded entry" message with some devices
- added kernel-fix-drivers-scsi:
  + 2.6_50_sata_sil-mod15write.patch: fix Seagate+SiI3112 mod15write bug
    workaround broken by the LBA48 optimizations

* Tue Jun 15 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt6
- kernel-fix-security added:
  + 2.6_50_fpu-exception.patch: fix FPU exception handling DoS

* Fri May 21 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt5
- updated to last kernel-fix-ide and kernel-fix-fs patches:
  + 2.6_55_reiserfs-i_size-race.patch: fix reiserfs inode size update race
    which could lead to file corruption
  + 2.6_52_no-suspend-on-reboot.patch: replaced with better fix (flush drive
    cache on reboot)
  + 2.6_51_dquot_release-oops.patch: fix dquot_release oops with quota_v1
  + 2.6_52_quota-recursion.patch: fixes quota recursion into filesystem
  + 2.6_53_quota-recursion-fix.patch: fix the recursion fix
  + 2.6_54_quota-v2-corruption.diff: fix possible quota_v2 files corruption
    when root did not have any inodes&space allocated
- added kernel-feat-pktcdvd

* Mon May 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt4
- config tuning:
    CONFIG_BLK_DEV_ATIIXP=y
    CONFIG_IP_NF_MATCH_IPRANGE=m
    CONFIG_IP_NF_MATCH_PHYSDEV=m
    * disabled debug on i2c
    * enabled ebtables
    * disabled CONFIG_FONT_MINI_4x6
    * moved CONFIG_X86_MCE_NONFATAL to modules
    * disabled CONFIG_IDEDMA_IVB
- added kernel-fix-drivers-ide (Sergey Vlasov) with:
  + 2.6_50_wcache-fixes.patch: fix write cache handling problems:
    + fix drive->wcache setting
    + send CACHE FLUSH (EXT) only if the drive claims to support it
    + fix for Maxtor disks falsely claiming CACHE FLUSH EXT support
  + 2.6_51_system_state.patch: differentiate between halt/poweroff/reboot
  + 2.6_52_no-suspend-on-reboot.patch: avoid drive spindown on reboot

* Tue May 11 2004 Anton Farygin <rider@altlinux.ru> 2.6.6-alt3
- 2.6.6
- fixed depends (kernel-headers-modules)
- added kernel-fix-acpi with:
    fixes IRQ12 sharing

 
- Added kernel-feat-drivers-console-unicode by Ivan Zakharyaschev <imz@altlinux.ru>:
  fixes the imperfectness of Linux VT/console Unicode support 
  (involves a change of the kernel interface used by loadkeys, 
  but mainly is compatible with old loadkeys).

* Mon Apr 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.5-alt2
- fixed requires (kernel-headers-common >= 1.1.5), bugzilla #3892


* Mon Apr 05 2004 Anton Farygin <rider@altlinux.ru> 2.6.5-alt1
- 2.6.5
- added squashfs patch
- enabled forcedeth driver (CONFIG_FORCEDETH=m)
- added kernel-doc-std26 package
- updated trackpoint patch
- updated splash patch


* Thu Mar 22 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt4
- fixed requires (mkinitrd >= 2.9.1-alt1, modutils >= 2.4.27-alt1)
- some cpufreq feathures moved to modules
- enabled PF_KEYv2 socket family support
- temporary disabled software suspend
- temporary disabled PREEMPT
- updated bootsplash patch from Gentoo (with fixed kernel oops on boot)
- added Provides: alsa = 1.0.3
- added lirc modules
- disabled drm modules

* Wed Mar 17 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt3
- removed Provides kernel-headers-std
- fixed permissions for files into /boot

* Thu Mar 11 2004 Anton Farygin <rider@altlinux.ru> 2.6.4-alt2
- 2.6.4

* Wed Feb 18 2004 Anton Farygin <rider@altlinux.ru> 2.6.3-alt1
- 2.6.3

* Tue Feb 17 2004 Rider <rider@altlinux.ru> 2.6.2-alt2
- removed symlinking to default kernel on post-install stage

* Wed Feb  4 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.2-alt1
- 2.6.2
- CONFIG_HIGHMEM4G=y (64G caused an reboot on Centrino-based notebooks)
- CONFIG_MAGIC_SYSRQ=y

* Tue Jan 20 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt5
- evms 2.2.2
- packet CD writing support
- CD-MRW (Mt Rainier) support
- CONFIG_BLK_DEV_IDEPNP was turned off
- some headers from ./drivers/char/drm/ added to the kernel-headers-modules
- kernel-modpost package removed
- xfs bug fixed

* Sat Jan 17 2004 Gleb Stiblo <ulfr@altlinux.org> 2.6.1-alt4
- framebuffer added!
- splash added

* Thu Jan 15 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt3
- initrd size increased to 12288 Kb
- DM and EVMS fixes added
- spec sanity check: %%defattr removed

* Wed Jan  14 2004 Gleb Stiblo <ulfr@altlinux.org> 2.6.1-alt2
- some files to kernel-headers-modules
- Makefiles hacks
- initrd size increased to 8192 Kb

* Fri Jan  9 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.1-alt1
- 2.6.1
- gcc 3.3
- Default Linux Capabilities build into the kernel
- NSA SELinux Support removed

* Thu Jan  8 2004 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt3
- kernel-fix-security patchset added (CAN-2003-0985 mremap fix and capability fix)
- NSA SELinux Support added

* Tue Dec 23 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt2
- IDE chipsets are compiled into the kernel now

* Thu Dec 18 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0-alt1
- rebuild for 2.6.0 release
- fix-core and fix-fs added

* Wed Dec 17 2003 Ed V. Bartosh <ed@altlinux.org> 2.6.0test11-alt2
- symlink 'include' added to the kernel-modules-headers package

* Thu Dec  4 2003 Ed V. Bartosh <ed@altlinux.ru> 2.6.0test11-alt1
- 2.6test11
- spec improvements
- 'kernel-modpost' package added

* Sat Nov 29 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt12
- Updated kernel-fix-security:
  + fixed CAN-2003-0001, CAN-2003-0461, CAN-2003-0961

* Fri Nov 28 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt11
- Updated kernel-fix-fs:
  + fixed iso9660 mount options handling
- Added kernel-fix-security.
- Updated kernel-feat-acpi:
  + new ACPI patch (ACPI hotplug fix, pci=noacpi fix)
- Updated kernel-feat-cpufreq:
  + speedstep-smi driver fixes
- Updated kernel-feat-drivers-libata:
  + updated libata patch to 2.4.23-rc3-libata1:
    - fixed a bug which may cause some devices to "not be talked to" at probe
      time (fixed flush of Device Control register to device)
    - ServerWorks-specific tweaks
  + added Intel Software RAID (ICH5R) support (iswraid module)
- Modified security configuration:
  + Non-executable user stack area enabled (with GCC trampolines
    autodetection): CONFIG_HARDEN_STACK=y, CONFIG_HARDEN_STACK_SMART=y
  + Restricted /proc enabled: CONFIG_HARDEN_PROC=y

* Wed Nov 19 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt10
- Fixed file lists for kernel-headers-%%flavour:
  + added acpi/, crypto/, freeswan.h, freeswan/, pfkey.h, pfkeyv2.h, zlib/
- Fixed kernel-headers-modules-%%flavour dependencies.
- Modified configuration:
  - adma100, sc1200, siimage drivers are now built into the kernel (building
    IDE controller drivers as modules does not work unless the whole IDE
    subsystem is in modules too)
  - tvmixer module is not built (now it is in kernel-modules-v4l-%%flavour)
- Added kernel-fix-drivers-pnp:
  + fixed problems with detection of some ISA PnP cards
- Updated kernel-fix-drivers-net:
  + fixed multicast list handling in the tulip driver
- Updated kernel-fix-drivers-scsi:
  + sg driver bugfix: do not accept negative sizes in SG_SET_RESERVED_SIZE
- Updates kernel-fix-fs:
  + fixed quota stats accounting bug
  + fixed races on inode deletion (could cause oops with NFS)
- Updated kernel-feat-acpi:
  + new ACPI patch (IRQ assignment fixes, poweroff fix)
- Updated kernel-feat-drivers-libata:
  + new upstream version (Promise driver bugfixes)
  + added support for Promise FastTrak 376

* Sat Nov 15 2003 Albert R. Valiev <darkstar@altlinux.ru> 2.4.22-alt9
- Added kernel-feat-driver-net-pcnet32-old patch 
- fix for vmware network card driver

* Sun Nov 09 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt8
- Updated kernel-feat-acpi (ACPI updates and fixes, Alt-SysRq poweroff fix).
- Updated kernel-feat-drivers-libata (new version, Promise SATA driver
  significantly enhanced).
- Updated kernel-fix-drivers-scsi (updated ServeRAID and MegaRAID drivers, SCSI
  blacklist updates).
- Added kernel-fix-drivers-cdrom (bugfixes).
- Updated kernel-fix-core, kernel-fix-drivers-char, kernel-fix-drivers-ide,
  kernel-fix-drivers-ieee1394, kernel-fix-drivers-net, kernel-fix-drivers-pci,
  kernel-fix-drivers-sound, kernel-fix-drivers-usb, kernel-fix-fs,
  kernel-fix-lvm, kernel-fix-net (lots of bugfixes).
- Relaxed BuildRequires (libdb4.0-devel -> libdb4-devel) (#2826).

* Sun Oct 19 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt7
- Updated kernel-feat-acpi (important bugfixes; enabled DMI info dump; moved
  ACPI BIOS date cutoff from 2001 to 2000).
- Added kernel-fix-lvm (makes LVM snapshots work with journaling FS).
- Added documentation subpackage (common for std-up and std-smp flavours).
- Added kernel-feat-libata (Serial ATA drivers). Supported devices: Intel ICH5,
  Promise FastTrak S150 TX2plus/TX4/SX4, Broadcom (Apple K2) SATA, VIA SATA.
  Silicon Image SATA support not enabled (does not work yet).
- Updated kernel-feat-i2c (2.8.1 release).

* Tue Oct 07 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt6
- updated kernel-feat-net-ppp-mppe (this version should really work)
- updated kernel-feat-crypto:
  - back to old cryptoapi from kerneli.org
- moved .config to kernel-headers-modules
- added toplevel Makefile and Rules.make to kernel-headers-modules (needed for
  compilation of some external modules)
- added kernel-feat-cpufreq (frequency/voltage scaling support)
- removed kernel-feat-bttv, kernel-feat-saa7134 (now in kernel-modules-v4l)
- removed kernel-feat-addon (no longer used)
- updated kernel-feat-acpi (more fixes)
- turned off OV511 USB camera driver (now in kernel-modules-v4l)

* Mon Sep 29 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt5
- updated kernel-fix-net:
  - hidden IGMPv3 definitions in <linux/in.h> from userspace (workaround for
    #3053)
- updated kernel-fix-drivers-usb, kernel-feat-drivers-usb:
  - lots of bugfixes and new device IDs
- updated kernel-fix-drivers-char:
  - added AGP support for Intel 875 (integrated video not supported)
- fixed kernel-headers-modules building:
  - install updated bttv headers instead of obsolete ones

* Wed Sep 24 2003 Sergey Vlasov <vsu@altlinux.ru> 2.4.22-alt4
- added kernel-feat-acpi:
    + ACPI update 20030916-2.4.22 (should fix some problems with nForce)
    + DSDT override from initrd
    + blacklist updates
- added kernel-fix-drivers-mtd, kernel-fix-drivers-sound,
  kernel-fix-drivers-video:
    + missing MODULE_LICENSE fixes
- updated kernel-fix-drivers-char:
    + fixed AGP 3.0 support for Via KT400
    + added AGP support for Intel 7x05, ATI Radeon IGP, Via CLE266
- updated kernel-fix-drivers-pci:
    + enable SMBus controller on ASUS boards
- added kernel-headers-modules-%flavour package (Rider)
- added provides: kernel24-headers (Rider)
- added kernel-feat-drivers-sound-emu10k1 (Rider)
    + update emu10k1 to 0.20a
- added drivers/media/video/ headers to kernel-headers-modules package (Rider)
- disabled 8139cp (PCI ID conflict with 8139too)
- added kernel-fix-drivers-ieee1394, kernel-fix-drivers-atm

* Thu Sep 11 2003 Anton Farygin <rider@altlinux.ru> 2.4.22-alt3
- enabled aic79xx module by default
- updated sk98lin driver for support 3c940 and other (based on sk98)  ethernet cards
- enabled CONFIG_4GB option
- build ATM support for UP kernel

* Tue Sep 09 2003 Anton Farygin <rider@altlinux.ru> 2.4.22-alt2
- fixed bug with build userspace v4l programms

* Tue Sep 02 2003 Rider <rider@altlinux.ru> 2.4.22-alt1
- update to 2.4.22
- removed ACPI patches (mainstream)
- removed O(1)sheduler

* Tue Aug 26 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt14
- played with OWL patch configs. installator should work just fine now.

* Thu Aug 14 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt13
- added Video4Linux Version 2 API patch.
- added kernel-fix-drivers-md.
- added saa7134 driver.

* Wed Aug 13 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt12
- removed percentexclude pcmcia dir.

* Mon Aug 11 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt11
- getting back bttv.

* Mon Aug 11 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt10
- upgraded patches.
- added patches:
  + kernel-fix-drivers-char
  + kernel-fix-drivers-video
- temporary removed patches:
  - kernel-feat-bttv

* Thu Aug 07 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt9
- got back all the pcmcia inkernel drivers, as 3.2.4 are considered as
  experimental.

* Thu Jul 31 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt8
- added kernel-headers to provides of kernel-headers-%{flavour}.
- replaced get_patch_list with format_patch_list.
- rebuilt with new kernel-fix-core with new dcache names patch. start-stop-daemon
  should work now.
- added asm-generic directory to headers.
- don't build pcmcia modules inside the kernel.

* Wed Jul 30 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt7
- removed iscsi patch as rider@ and ab@ suggested.

* Thu Jul 17 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt6
- Added provides kernel24
- ACPI support now included (+ kernel-feat-acpi)
- Fixed OWL security patch configuration, proc is now visible to all in
  std kernels.

* Tue Jul 15 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt5
- new patches:
  + kernel-fix-fs

* Wed Jul 09 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt4
- compiled Promise PDC drivers in kernel (satisfying request by mouse@a.r).

* Mon Jul 07 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt3
- new patches:
  + kernel-fix-drivers
  \ + ide 
    + net
    + pci 
    + scsi
    + usb
    + security-owl
  + kernel-feat
  \ + fs-ntfs
    + i2c
- fixed spec in many places
- changed /etc/apt/apt.cond.d/file filename so that kernel packages with different versions installed at one time
  don't conflict.

* Sat Jun 21 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rel-alt1
- upgraded to rc7
- applied patches:
  + kernel-fix-core
  + kernel-feat-core-O1sched
  + kernel-feat-iscsi 
  + kernel-feat-bttv
  + kernel-feat-fs-xfs
  + kernel-feat-kconfig
  + kernel-feat-addon
  + kernel-feat-crypto
  + kernel-feat-drivers-video-splash
  + kernel-feat-net-ipsec
  \ + ipsec
    + ppp-mppe

* Mon May 26 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rc1-alt3
- compile ext2 filesystem in kernel for installer needs.
- added net-ipsec and video-splash features.

* Thu May 15 2003 Peter Novodvorsky <nidd@altlinux.com> 2.4.21rc1-alt2
- removed crypto patch because it bugs loop filesystem. ... And added 
  it again, because it doesn't.

* Fri Apr 25 2003 Peter Novodvorsky <nidd@altlinux.com> kernel-policy-rc.2
- rc2 policy release.

